@@ -4,7 +4,6 @@ require "compass-rails/configuration"
 
 module CompassRails
 
-    RAILS_4 = %r{^4.[0|1|2]}
     RAILS_32 = %r{^3.2}
     RAILS_31 = %r{^3.1}
 
@@ -66,11 +65,6 @@ module CompassRails
       version_match RAILS_32
     end
 
-    def rails4?
-      return false unless defined?(::Rails)
-      version_match RAILS_4
-    end
-
     def version_match(version)
       !(rails_version =~ version).nil?
     end
